
package Amazon::API::STS;

# Autogenerated Mon Jul  6 12:50:57 2026

use strict;
use warnings;

use Amazon::API::Botocore::Shape::Utils qw(register_service_shapes);
use File::ShareDir qw(dist_dir);
use Storable qw(retrieve);

use parent qw( Amazon::API );

our $VERSION = '2011.06.15';

########################################################################
sub _retrieve_botocore_descriptions {
########################################################################
  my $package = __PACKAGE__;

  $package =~s/::/-/gxsm;

  my ($service) = reverse split /-/xsm, $package;

  my $dist_dir = dist_dir($package);
  
  return retrieve("$dist_dir/$service.api");
};

########################################################################
sub new {
########################################################################
  my ( $class, @options ) = @_;
  $class = ref($class) || $class;

  my $botocore_descriptions = _retrieve_botocore_descriptions();

  my ($service) = reverse split /::/xsm, $class;

  register_service_shapes( $service, $botocore_descriptions->{shapes} );


  my %options = ref $options[0] ? %{ $options[0] } : @options;

  my $self = $class->SUPER::new(
    { service             => 'sts',
      endpoint_prefix     => 'sts',
      version             => '2011-06-15',
      target_prefix       => '',
      content_type        => 'application/x-www-form-urlencoded',
      botocore_metadata   => $botocore_descriptions->{metadata},
      botocore_operations => $botocore_descriptions->{operations},
      botocore_shapes     => $botocore_descriptions->{shapes},
      paginators          => $botocore_descriptions->{paginators},
      api_methods         => [ keys %{ $botocore_descriptions->{operations} } ],
      debug               => $ENV{DEBUG} // 0,
      decode_always       => 1,
      %options
    }
  );

  # global services should be signed with us-east-1 region
  if ( defined $self->get_botocore_metadata->{globalEndpoint} ) {
    $self->set_region('us-east-1');
  }
  
  return $self;
} 

1;

__END__

=pod

=encoding utf8

=head1 NAME

Amazon::API::STS

=head1 DESCRIPTION

AWS Security Token Service

=head1 VERSION

Version 2.4.2

=head1 METHODS AND SUBROUTINES


=head2 AssumeRole

Returns a set of temporary security credentials that you can use to
access Amazon Web Services resources. These temporary credentials
consist of an access key ID, a secret access key, and a security token.
Typically, you use C<AssumeRole> within your account or for
cross-account access. For a comparison of C<AssumeRole> with other API
operations that produce temporary credentials, see Requesting Temporary
Security Credentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html)
and Compare STS credentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_sts-comparison.html)
in the I<IAM User Guide>.

B<Permissions>

The temporary security credentials created by C<AssumeRole> can be used
to make API calls to any Amazon Web Services service with the following
exception: You cannot call the Amazon Web Services STS
C<GetFederationToken> or C<GetSessionToken> API operations.

(Optional) You can pass inline or managed session policies to this
operation. You can pass a single JSON policy document to use as an
inline session policy. You can also specify up to 10 managed policy
Amazon Resource Names (ARNs) to use as managed session policies. The
plaintext that you use for both inline and managed session policies
can't exceed 2,048 characters. Passing policies to this operation
returns new temporary credentials. The resulting session's permissions
are the intersection of the role's identity-based policy and the
session policies. You can use the role's temporary credentials in
subsequent Amazon Web Services API calls to access resources in the
account that owns the role. You cannot use session policies to grant
more permissions than those allowed by the identity-based policy of the
role that is being assumed. For more information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>.

When you create a role, you create two policies: a role trust policy
that specifies I<who> can assume the role, and a permissions policy
that specifies I<what> can be done with the role. You specify the
trusted principal that is allowed to assume the role in the role trust
policy.

To assume a role from a different account, your Amazon Web Services
account must be trusted by the role. The trust relationship is defined
in the role's trust policy when the role is created. That trust policy
states which accounts are allowed to delegate that access to users in
the account.

A user who wants to access a role in a different account must also have
permissions that are delegated from the account administrator. The
administrator must attach a policy that allows the user to call
C<AssumeRole> for the ARN of the role in the other account.

To allow a user to assume a role in the same account, you can do either
of the following:

=over

=item *

Attach a policy to the user that allows the user to call C<AssumeRole>
(as long as the role's trust policy trusts the account).

=item *

Add the user as a principal directly in the role's trust policy.

=back

You can do either because the roleE<rsquo>s trust policy acts as an IAM
resource-based policy. When a resource-based policy grants access to a
principal in the same account, no additional identity-based policy is
required. For more information about trust policies and resource-based
policies, see IAM Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html)
in the I<IAM User Guide>.

B<Tags>

(Optional) You can pass tag key-value pairs to your session. These tags
are called session tags. For more information about session tags, see
Passing Session Tags in STS
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html)
in the I<IAM User Guide>.

An administrator must grant you the permissions necessary to pass
session tags. The administrator can also create granular permissions to
allow you to pass only specific session tags. For more information, see
Tutorial: Using Tags for Attribute-Based Access Control
(https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_attribute-based-access-control.html)
in the I<IAM User Guide>.

You can set the session tags as transitive. Transitive tags persist
during role chaining. For more information, see Chaining Roles with
Session Tags
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html#id_session-tags_role-chaining)
in the I<IAM User Guide>.

B<Using MFA with AssumeRole>

(Optional) You can include multi-factor authentication (MFA)
information when you call C<AssumeRole>. This is useful for
cross-account scenarios to ensure that the user that assumes the role
has been authenticated with an Amazon Web Services MFA device. In that
scenario, the trust policy of the role being assumed includes a
condition that tests for MFA authentication. If the caller does not
include valid MFA information, the request to assume the role is
denied. The condition in a trust policy that tests for MFA
authentication might look like the following example.

C<"Condition": {"Bool": {"aws:MultiFactorAuthPresent": true}}>

For more information, see Configuring MFA-Protected API Access
(https://docs.aws.amazon.com/IAM/latest/UserGuide/MFAProtectedAPI.html)
in the I<IAM User Guide> guide.

To use MFA with C<AssumeRole>, you pass values for the C<SerialNumber>
and C<TokenCode> parameters. The C<SerialNumber> value identifies the
user's hardware or virtual MFA device. The C<TokenCode> is the
time-based one-time password (TOTP) that the MFA device produces.

=over 5

=item INPUT


=over 5

=item AssumeRoleRequest

=over 5

=item Parameters

=over 5


=item DurationSeconds

The duration, in seconds, of the role session. The value specified can
range from 900 seconds (15 minutes) up to the maximum session duration
set for the role. The maximum session duration setting can have a value
from 1 hour to 12 hours. If you specify a value higher than this
setting or the administrator setting (whichever is lower), the
operation fails. For example, if you specify a session duration of 12
hours, but your administrator set the maximum session duration to 6
hours, your operation fails.

Role chaining limits your Amazon Web Services CLI or Amazon Web
Services API role session to a maximum of one hour. When you use the
C<AssumeRole> API operation to assume a role, you can specify the
duration of your role session with the C<DurationSeconds> parameter.
You can specify a parameter value of up to 43200 seconds (12 hours),
depending on the maximum session duration setting for your role.
However, if you assume a role using role chaining and provide a
C<DurationSeconds> parameter value greater than one hour, the operation
fails. To learn how to view the maximum value for your role, see Update
the maximum session duration for a role
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_update-role-settings.html#id_roles_update-session-duration).

By default, the value is set to C<3600> seconds.

The C<DurationSeconds> parameter is separate from the duration of a
console session that you might request using the returned credentials.
The request to the federation endpoint for a console sign-in token
takes a C<SessionDuration> parameter that specifies the maximum length
of the console session. For more information, see Creating a URL that
Enables Federated Users to Access the Amazon Web Services Management
Console
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_enable-console-custom-url.html)
in the I<IAM User Guide>.

=item ExternalId

A unique identifier that might be required when you assume a role in
another account. If the administrator of the account to which the role
belongs provided you with an external ID, then provide that value in
the C<ExternalId> parameter. This value can be any string, such as a
passphrase or account number. A cross-account role is usually set up to
trust everyone in an account. Therefore, the administrator of the
trusting account might send an external ID to the administrator of the
trusted account. That way, only someone with the ID can assume the
role, rather than everyone in the account. For more information about
the external ID, see How to Use an External ID When Granting Access to
Your Amazon Web Services Resources to a Third Party
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-user_externalid.html)
in the I<IAM User Guide>.

The regex used to validate this parameter is a string of characters
consisting of upper- and lower-case alphanumeric characters with no
spaces. You can also include underscores or any of the following
characters: +=,.@:\/-

=item Policy

An IAM policy in JSON format that you want to use as an inline session
policy.

This parameter is optional. Passing policies to this operation returns
new temporary credentials. The resulting session's permissions are the
intersection of the role's identity-based policy and the session
policies. You can use the role's temporary credentials in subsequent
Amazon Web Services API calls to access resources in the account that
owns the role. You cannot use session policies to grant more
permissions than those allowed by the identity-based policy of the role
that is being assumed. For more information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>.

The plaintext that you use for both inline and managed session policies
can't exceed 2,048 characters. The JSON policy characters can be any
ASCII character from the space character to the end of the valid
character list (\u0020 through \u00FF). It can also include the tab
(\u0009), linefeed (\u000A), and carriage return (\u000D) characters.

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

For more information about role session permissions, see Session
policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session).

=item PolicyArns

The Amazon Resource Names (ARNs) of the IAM managed policies that you
want to use as managed session policies. The policies must exist in the
same account as the role.

This parameter is optional. You can provide up to 10 managed policy
ARNs. However, the plaintext that you use for both inline and managed
session policies can't exceed 2,048 characters. For more information
about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services
Service Namespaces
(https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)
in the Amazon Web Services General Reference.

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

Passing policies to this operation returns new temporary credentials.
The resulting session's permissions are the intersection of the role's
identity-based policy and the session policies. You can use the role's
temporary credentials in subsequent Amazon Web Services API calls to
access resources in the account that owns the role. You cannot use
session policies to grant more permissions than those allowed by the
identity-based policy of the role that is being assumed. For more
information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>.

=item ProvidedContexts

A list of previously acquired trusted context assertions in the format
of a JSON array. The trusted context assertion is signed and encrypted
by Amazon Web Services STS.

The following is an example of a C<ProvidedContext> value that includes
a single trusted context assertion and the ARN of the context provider
from which the trusted context assertion was generated.

C<[{"ProviderArn":"arn:aws:iam::aws:contextProvider/IdentityCenter","ContextAssertion":"trusted-context-assertion"}]>

=item RoleArn

The Amazon Resource Name (ARN) of the role to assume.

=item RoleSessionName

An identifier for the assumed role session.

Use the role session name to uniquely identify a session when the same
role is assumed by different principals or for different reasons. In
cross-account scenarios, the role session name is visible to, and can
be logged by the account that owns the role. The role session name is
also used in the ARN of the assumed role principal. This means that
subsequent cross-account API requests that use the temporary security
credentials will expose the role session name to the external account
in their CloudTrail logs.

For security purposes, administrators can view this field in CloudTrail
logs
(https://docs.aws.amazon.com/IAM/latest/UserGuide/cloudtrail-integration.html#cloudtrail-integration_signin-tempcreds)
to help identify who performed an action in Amazon Web Services. Your
administrator might require that you specify your user name as the
session name when you assume the role. For more information, see
C<sts:RoleSessionName>
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_rolesessionname).

The regex used to validate this parameter is a string of characters
consisting of upper- and lower-case alphanumeric characters with no
spaces. You can also include underscores or any of the following
characters: +=,.@-

=item SerialNumber

The identification number of the MFA device that is associated with the
user who is making the C<AssumeRole> call. Specify this value if the
trust policy of the role being assumed includes a condition that
requires MFA authentication. The value is either the serial number for
a hardware device (such as C<GAHT12345678>) or an Amazon Resource Name
(ARN) for a virtual device (such as
C<arn:aws:iam::123456789012:mfa/user>).

The regex used to validate this parameter is a string of characters
consisting of upper- and lower-case alphanumeric characters with no
spaces. You can also include underscores or any of the following
characters: +=/:,.@-

=item SourceIdentity

The source identity specified by the principal that is calling the
C<AssumeRole> operation. The source identity value persists across
chained role
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html#iam-term-role-chaining)
sessions.

You can require users to specify a source identity when they assume a
role. You do this by using the C<sts:SourceIdentity>
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_condition-keys.html#condition-keys-sourceidentity)
condition key in a role trust policy. You can use source identity
information in CloudTrail logs to determine who took actions with a
role. You can use the C<aws:SourceIdentity> condition key to further
control access to Amazon Web Services resources based on the value of
source identity. For more information about using source identity, see
Monitor and control actions taken with assumed roles
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_control-access_monitor.html)
in the I<IAM User Guide>.

The regex used to validate this parameter is a string of characters
consisting of upper- and lower-case alphanumeric characters with no
spaces. You can also include underscores or any of the following
characters: +=,.@-. You cannot use a value that begins with the text
C<aws:>. This prefix is reserved for Amazon Web Services internal use.

=item Tags

A list of session tags that you want to pass. Each session tag consists
of a key name and an associated value. For more information about
session tags, see Tagging Amazon Web Services STS Sessions
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html)
in the I<IAM User Guide>.

This parameter is optional. You can pass up to 50 session tags. The
plaintext session tag keys canE<rsquo>t exceed 128 characters, and the
values canE<rsquo>t exceed 256 characters. For these and additional
limits, see IAM and STS Character Limits
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-limits.html#reference_iam-limits-entity-length)
in the I<IAM User Guide>.

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

You can pass a session tag with the same key as a tag that is already
attached to the role. When you do, session tags override a role tag
with the same key.

Tag keyE<ndash>value pairs are not case sensitive, but case is
preserved. This means that you cannot have separate C<Department> and
C<department> tag keys. Assume that the role has the
C<Department>=C<Marketing> tag and you pass the
C<department>=C<engineering> session tag. C<Department> and
C<department> are not saved as separate tags, and the session tag
passed in the request takes precedence over the role tag.

Additionally, if you used temporary credentials to perform this
operation, the new session inherits any transitive session tags from
the calling session. If you pass a session tag with the same key as an
inherited tag, the operation fails. To view the inherited tags for a
session, see the CloudTrail logs. For more information, see Viewing
Session Tags in CloudTrail
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html#id_session-tags_ctlogs)
in the I<IAM User Guide>.

=item TokenCode

The value provided by the MFA device, if the trust policy of the role
being assumed requires MFA. (In other words, if the policy includes a
condition that tests for MFA). If the role being assumed requires MFA
and if the C<TokenCode> value is missing or expired, the C<AssumeRole>
call returns an "access denied" error.

The format for this parameter, as described by its regex pattern, is a
sequence of six numeric digits.

=item TransitiveTagKeys

A list of keys for session tags that you want to set as transitive. If
you set a tag key as transitive, the corresponding key and value passes
to subsequent sessions in a role chain. For more information, see
Chaining Roles with Session Tags
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html#id_session-tags_role-chaining)
in the I<IAM User Guide>.

This parameter is optional. The transitive status of a session tag does
not impact its packed binary size.

If you choose not to specify a transitive tag key, then no tags are
passed from this session to any subsequent sessions.


=back

=item Required

=over 5

=item RoleArn

=item RoleSessionName


=back

=back

=back



=item OUTPUT


=over 5

=item AssumeRoleResponse

=over 5

=item Parameters

=over 5


=item AssumedRoleUser

The Amazon Resource Name (ARN) and the assumed role ID, which are
identifiers that you can use to refer to the resulting temporary
security credentials. For example, you can reference these credentials
as a principal in a resource-based policy by using the ARN or assumed
role ID. The ARN and ID include the C<RoleSessionName> that you
specified when you called C<AssumeRole>.

=item Credentials

The temporary security credentials, which include an access key ID, a
secret access key, and a security (or session) token.

The size of the security token that STS API operations return is not
fixed. We strongly recommend that you make no assumptions about the
maximum size.

=item PackedPolicySize

A percentage value that indicates the packed size of the session
policies and session tags combined passed in the request. The request
fails if the packed size is greater than 100 percent, which means the
policies and tags exceeded the allowed space.

=item SourceIdentity

The source identity specified by the principal that is calling the
C<AssumeRole> operation.

You can require users to specify a source identity when they assume a
role. You do this by using the C<sts:SourceIdentity> condition key in a
role trust policy. You can use source identity information in
CloudTrail logs to determine who took actions with a role. You can use
the C<aws:SourceIdentity> condition key to further control access to
Amazon Web Services resources based on the value of source identity.
For more information about using source identity, see Monitor and
control actions taken with assumed roles
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_control-access_monitor.html)
in the I<IAM User Guide>.

The regex used to validate this parameter is a string of characters
consisting of upper- and lower-case alphanumeric characters with no
spaces. You can also include underscores or any of the following
characters: =,.@-


=back

=back

=back



=item ERRORS


=over 5

=item MalformedPolicyDocumentException

The request was rejected because the policy document was malformed. The
error message describes the specific error.


=over 5

=item code

MalformedPolicyDocument

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item PackedPolicyTooLargeException

The request was rejected because the total packed size of the session
policies and session tags combined was too large. An Amazon Web
Services conversion compresses the session policy document, session
policy ARNs, and session tags into a packed binary format that has a
separate limit. The error message indicates by percentage how close the
policies and tags are to the upper size limit. For more information,
see Passing Session Tags in STS
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html)
in the I<IAM User Guide>.

You could receive this error even though you meet other defined session
policy and session tag limits. For more information, see IAM and STS
Entity Character Limits
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html#reference_iam-limits-entity-length)
in the I<IAM User Guide>.


=over 5

=item code

PackedPolicyTooLarge

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item RegionDisabledException

STS is not activated in the requested region for the account that is
being asked to generate credentials. The account administrator must use
the IAM console to activate STS in that region. For more information,
see Activating and Deactivating STS in an Amazon Web Services Region
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html#sts-regions-activate-deactivate)
in the I<IAM User Guide>.


=over 5

=item code

RegionDisabledException

=item httpStatusCode

403

=item senderFault

1

=back


=back


=over 5

=item ExpiredTokenException

The web identity token that was passed is expired or is not valid. Get
a new identity token from the identity provider and then retry the
request.


=over 5

=item code

ExpiredTokenException

=item httpStatusCode

400

=item senderFault

1

=back


=back




=back


=over 5

=item METHOD

POST

=item REQUEST URI

/

=back



=head2 AssumeRoleWithSAML

Returns a set of temporary security credentials for users who have been
authenticated via a SAML authentication response. This operation
provides a mechanism for tying an enterprise identity store or
directory to role-based Amazon Web Services access without
user-specific credentials or configuration. For a comparison of
C<AssumeRoleWithSAML> with the other API operations that produce
temporary credentials, see Requesting Temporary Security Credentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html)
and Compare STS credentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_sts-comparison.html)
in the I<IAM User Guide>.

The temporary security credentials returned by this operation consist
of an access key ID, a secret access key, and a security token.
Applications can use these temporary security credentials to sign calls
to Amazon Web Services services.

AssumeRoleWithSAML will not work on IAM Identity Center managed roles.
These roles' names start with C<AWSReservedSSO_>.

B<Session Duration>

By default, the temporary security credentials created by
C<AssumeRoleWithSAML> last for one hour. However, you can use the
optional C<DurationSeconds> parameter to specify the duration of your
session. Your role session lasts for the duration that you specify, or
until the time specified in the SAML authentication response's
C<SessionNotOnOrAfter> value, whichever is shorter. You can provide a
C<DurationSeconds> value from 900 seconds (15 minutes) up to the
maximum session duration setting for the role. This setting can have a
value from 1 hour to 12 hours. To learn how to view the maximum value
for your role, see View the Maximum Session Duration Setting for a Role
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html#id_roles_use_view-role-max-session)
in the I<IAM User Guide>. The maximum session duration limit applies
when you use the C<AssumeRole*> API operations or the C<assume-role*>
CLI commands. However the limit does not apply when you use those
operations to create a console URL. For more information, see Using IAM
Roles
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html) in
the I<IAM User Guide>.

Role chaining
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_terms-and-concepts.html#iam-term-role-chaining)
limits your CLI or Amazon Web Services API role session to a maximum of
one hour. When you use the C<AssumeRole> API operation to assume a
role, you can specify the duration of your role session with the
C<DurationSeconds> parameter. You can specify a parameter value of up
to 43200 seconds (12 hours), depending on the maximum session duration
setting for your role. However, if you assume a role using role
chaining and provide a C<DurationSeconds> parameter value greater than
one hour, the operation fails.

B<Permissions>

The temporary security credentials created by C<AssumeRoleWithSAML> can
be used to make API calls to any Amazon Web Services service with the
following exception: you cannot call the STS C<GetFederationToken> or
C<GetSessionToken> API operations.

(Optional) You can pass inline or managed session policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
to this operation. You can pass a single JSON policy document to use as
an inline session policy. You can also specify up to 10 managed policy
Amazon Resource Names (ARNs) to use as managed session policies. The
plaintext that you use for both inline and managed session policies
can't exceed 2,048 characters. Passing policies to this operation
returns new temporary credentials. The resulting session's permissions
are the intersection of the role's identity-based policy and the
session policies. You can use the role's temporary credentials in
subsequent Amazon Web Services API calls to access resources in the
account that owns the role. You cannot use session policies to grant
more permissions than those allowed by the identity-based policy of the
role that is being assumed. For more information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>.

Calling C<AssumeRoleWithSAML> does not require the use of Amazon Web
Services security credentials. The identity of the caller is validated
by using keys in the metadata document that is uploaded for the SAML
provider entity for your identity provider.

Calling C<AssumeRoleWithSAML> can result in an entry in your CloudTrail
logs. The entry includes the value in the C<NameID> element of the SAML
assertion. We recommend that you use a C<NameIDType> that is not
associated with any personally identifiable information (PII). For
example, you could instead use the persistent identifier
(C<urn:oasis:names:tc:SAML:2.0:nameid-format:persistent>).

B<Tags>

(Optional) You can configure your IdP to pass attributes into your SAML
assertion as session tags. Each session tag consists of a key name and
an associated value. For more information about session tags, see
Passing Session Tags in STS
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html)
in the I<IAM User Guide>.

You can pass up to 50 session tags. The plaintext session tag keys
canE<rsquo>t exceed 128 characters and the values canE<rsquo>t exceed
256 characters. For these and additional limits, see IAM and STS
Character Limits
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-limits.html#reference_iam-limits-entity-length)
in the I<IAM User Guide>.

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

You can pass a session tag with the same key as a tag that is attached
to the role. When you do, session tags override the role's tags with
the same key.

An administrator must grant you the permissions necessary to pass
session tags. The administrator can also create granular permissions to
allow you to pass only specific session tags. For more information, see
Tutorial: Using Tags for Attribute-Based Access Control
(https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_attribute-based-access-control.html)
in the I<IAM User Guide>.

You can set the session tags as transitive. Transitive tags persist
during role chaining. For more information, see Chaining Roles with
Session Tags
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html#id_session-tags_role-chaining)
in the I<IAM User Guide>.

B<SAML Configuration>

Before your application can call C<AssumeRoleWithSAML>, you must
configure your SAML identity provider (IdP) to issue the claims
required by Amazon Web Services. Additionally, you must use Identity
and Access Management (IAM) to create a SAML provider entity in your
Amazon Web Services account that represents your identity provider. You
must also create an IAM role that specifies this SAML provider in its
trust policy.

For more information, see the following resources:

=over

=item *

About SAML 2.0-based Federation
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_saml.html)
in the I<IAM User Guide>.

=item *

Creating SAML Identity Providers
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_create_saml.html)
in the I<IAM User Guide>.

=item *

Configuring a Relying Party and Claims
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_create_saml_relying-party.html)
in the I<IAM User Guide>.

=item *

Creating a Role for SAML 2.0 Federation
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_create_for-idp_saml.html)
in the I<IAM User Guide>.

=back

=over 5

=item INPUT


=over 5

=item AssumeRoleWithSAMLRequest

=over 5

=item Parameters

=over 5


=item DurationSeconds

The duration, in seconds, of the role session. Your role session lasts
for the duration that you specify for the C<DurationSeconds> parameter,
or until the time specified in the SAML authentication response's
C<SessionNotOnOrAfter> value, whichever is shorter. You can provide a
C<DurationSeconds> value from 900 seconds (15 minutes) up to the
maximum session duration setting for the role. This setting can have a
value from 1 hour to 12 hours. If you specify a value higher than this
setting, the operation fails. For example, if you specify a session
duration of 12 hours, but your administrator set the maximum session
duration to 6 hours, your operation fails. To learn how to view the
maximum value for your role, see View the Maximum Session Duration
Setting for a Role
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html#id_roles_use_view-role-max-session)
in the I<IAM User Guide>.

By default, the value is set to C<3600> seconds.

The C<DurationSeconds> parameter is separate from the duration of a
console session that you might request using the returned credentials.
The request to the federation endpoint for a console sign-in token
takes a C<SessionDuration> parameter that specifies the maximum length
of the console session. For more information, see Creating a URL that
Enables Federated Users to Access the Amazon Web Services Management
Console
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_enable-console-custom-url.html)
in the I<IAM User Guide>.

=item Policy

An IAM policy in JSON format that you want to use as an inline session
policy.

This parameter is optional. Passing policies to this operation returns
new temporary credentials. The resulting session's permissions are the
intersection of the role's identity-based policy and the session
policies. You can use the role's temporary credentials in subsequent
Amazon Web Services API calls to access resources in the account that
owns the role. You cannot use session policies to grant more
permissions than those allowed by the identity-based policy of the role
that is being assumed. For more information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>.

The plaintext that you use for both inline and managed session policies
can't exceed 2,048 characters. The JSON policy characters can be any
ASCII character from the space character to the end of the valid
character list (\u0020 through \u00FF). It can also include the tab
(\u0009), linefeed (\u000A), and carriage return (\u000D) characters.

For more information about role session permissions, see Session
policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session).

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

=item PolicyArns

The Amazon Resource Names (ARNs) of the IAM managed policies that you
want to use as managed session policies. The policies must exist in the
same account as the role.

This parameter is optional. You can provide up to 10 managed policy
ARNs. However, the plaintext that you use for both inline and managed
session policies can't exceed 2,048 characters. For more information
about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services
Service Namespaces
(https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)
in the Amazon Web Services General Reference.

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

Passing policies to this operation returns new temporary credentials.
The resulting session's permissions are the intersection of the role's
identity-based policy and the session policies. You can use the role's
temporary credentials in subsequent Amazon Web Services API calls to
access resources in the account that owns the role. You cannot use
session policies to grant more permissions than those allowed by the
identity-based policy of the role that is being assumed. For more
information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>.

=item PrincipalArn

The Amazon Resource Name (ARN) of the SAML provider in IAM that
describes the IdP.

=item RoleArn

The Amazon Resource Name (ARN) of the role that the caller is assuming.

=item SAMLAssertion

The base64 encoded SAML authentication response provided by the IdP.

For more information, see Configuring a Relying Party and Adding Claims
(https://docs.aws.amazon.com/IAM/latest/UserGuide/create-role-saml-IdP-tasks.html)
in the I<IAM User Guide>.


=back

=item Required

=over 5

=item RoleArn

=item PrincipalArn

=item SAMLAssertion


=back

=back

=back



=item OUTPUT


=over 5

=item AssumeRoleWithSAMLResponse

=over 5

=item Parameters

=over 5


=item AssumedRoleUser

The identifiers for the temporary security credentials that the
operation returns.

=item Audience

The value of the C<Recipient> attribute of the
C<SubjectConfirmationData> element of the SAML assertion.

=item Credentials

The temporary security credentials, which include an access key ID, a
secret access key, and a security (or session) token.

The size of the security token that STS API operations return is not
fixed. We strongly recommend that you make no assumptions about the
maximum size.

=item Issuer

The value of the C<Issuer> element of the SAML assertion.

=item NameQualifier

A hash value based on the concatenation of the following:

=over

=item *

The C<Issuer> response value.

=item *

The Amazon Web Services account ID.

=item *

The friendly name (the last part of the ARN) of the SAML provider in
IAM.

=back

The combination of C<NameQualifier> and C<Subject> can be used to
uniquely identify a user.

The following pseudocode shows how the hash value is calculated:

C<BASE64 ( SHA1 ( "https://example.com/saml" + "123456789012" +
"/MySAMLIdP" ) )>

=item PackedPolicySize

A percentage value that indicates the packed size of the session
policies and session tags combined passed in the request. The request
fails if the packed size is greater than 100 percent, which means the
policies and tags exceeded the allowed space.

=item SourceIdentity

The value in the C<SourceIdentity> attribute in the SAML assertion. The
source identity value persists across chained role
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html#iam-term-role-chaining)
sessions.

You can require users to set a source identity value when they assume a
role. You do this by using the C<sts:SourceIdentity> condition key in a
role trust policy. That way, actions that are taken with the role are
associated with that user. After the source identity is set, the value
cannot be changed. It is present in the request for all actions that
are taken by the role and persists across chained role
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html#id_roles_terms-and-concepts)
sessions. You can configure your SAML identity provider to use an
attribute associated with your users, like user name or email, as the
source identity when calling C<AssumeRoleWithSAML>. You do this by
adding an attribute to the SAML assertion. For more information about
using source identity, see Monitor and control actions taken with
assumed roles
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_control-access_monitor.html)
in the I<IAM User Guide>.

The regex used to validate this parameter is a string of characters
consisting of upper- and lower-case alphanumeric characters with no
spaces. You can also include underscores or any of the following
characters: =,.@-

=item Subject

The value of the C<NameID> element in the C<Subject> element of the
SAML assertion.

=item SubjectType

The format of the name ID, as defined by the C<Format> attribute in the
C<NameID> element of the SAML assertion. Typical examples of the format
are C<transient> or C<persistent>.

If the format includes the prefix
C<urn:oasis:names:tc:SAML:2.0:nameid-format>, that prefix is removed.
For example, C<urn:oasis:names:tc:SAML:2.0:nameid-format:transient> is
returned as C<transient>. If the format includes any other prefix, the
format is returned with no modifications.


=back

=back

=back



=item ERRORS


=over 5

=item MalformedPolicyDocumentException

The request was rejected because the policy document was malformed. The
error message describes the specific error.


=over 5

=item code

MalformedPolicyDocument

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item PackedPolicyTooLargeException

The request was rejected because the total packed size of the session
policies and session tags combined was too large. An Amazon Web
Services conversion compresses the session policy document, session
policy ARNs, and session tags into a packed binary format that has a
separate limit. The error message indicates by percentage how close the
policies and tags are to the upper size limit. For more information,
see Passing Session Tags in STS
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html)
in the I<IAM User Guide>.

You could receive this error even though you meet other defined session
policy and session tag limits. For more information, see IAM and STS
Entity Character Limits
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html#reference_iam-limits-entity-length)
in the I<IAM User Guide>.


=over 5

=item code

PackedPolicyTooLarge

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item IDPRejectedClaimException

The identity provider (IdP) reported that authentication failed. This
might be because the claim is invalid.

If this error is returned for the C<AssumeRoleWithWebIdentity>
operation, it can also mean that the claim has expired or has been
explicitly revoked.


=over 5

=item code

IDPRejectedClaim

=item httpStatusCode

403

=item senderFault

1

=back


=back


=over 5

=item InvalidIdentityTokenException

The web identity token that was passed could not be validated by Amazon
Web Services. Get a new identity token from the identity provider and
then retry the request.


=over 5

=item code

InvalidIdentityToken

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item ExpiredTokenException

The web identity token that was passed is expired or is not valid. Get
a new identity token from the identity provider and then retry the
request.


=over 5

=item code

ExpiredTokenException

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item RegionDisabledException

STS is not activated in the requested region for the account that is
being asked to generate credentials. The account administrator must use
the IAM console to activate STS in that region. For more information,
see Activating and Deactivating STS in an Amazon Web Services Region
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html#sts-regions-activate-deactivate)
in the I<IAM User Guide>.


=over 5

=item code

RegionDisabledException

=item httpStatusCode

403

=item senderFault

1

=back


=back




=back


=over 5

=item METHOD

POST

=item REQUEST URI

/

=back



=head2 AssumeRoleWithWebIdentity

Returns a set of temporary security credentials for users who have been
authenticated in a mobile or web application with a web identity
provider. Example providers include the OAuth 2.0 providers Login with
Amazon and Facebook, or any OpenID Connect-compatible identity provider
such as Google or Amazon Cognito federated identities
(https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-identity.html).

For mobile applications, we recommend that you use Amazon Cognito. You
can use Amazon Cognito with the Amazon Web Services SDK for iOS
Developer Guide (http://aws.amazon.com/sdkforios/) and the Amazon Web
Services SDK for Android Developer Guide
(http://aws.amazon.com/sdkforandroid/) to uniquely identify a user. You
can also supply the user with a consistent identity throughout the
lifetime of an application.

To learn more about Amazon Cognito, see Amazon Cognito identity pools
(https://docs.aws.amazon.com/cognito/latest/developerguide/cognito-identity.html)
in I<Amazon Cognito Developer Guide>.

Calling C<AssumeRoleWithWebIdentity> does not require the use of Amazon
Web Services security credentials. Therefore, you can distribute an
application (for example, on mobile devices) that requests temporary
security credentials without including long-term Amazon Web Services
credentials in the application. You also don't need to deploy
server-based proxy services that use long-term Amazon Web Services
credentials. Instead, the identity of the caller is validated by using
a token from the web identity provider. For a comparison of
C<AssumeRoleWithWebIdentity> with the other API operations that produce
temporary credentials, see Requesting Temporary Security Credentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html)
and Compare STS credentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_sts-comparison.html)
in the I<IAM User Guide>.

The temporary security credentials returned by this API consist of an
access key ID, a secret access key, and a security token. Applications
can use these temporary security credentials to sign calls to Amazon
Web Services service API operations.

B<Session Duration>

By default, the temporary security credentials created by
C<AssumeRoleWithWebIdentity> last for one hour. However, you can use
the optional C<DurationSeconds> parameter to specify the duration of
your session. You can provide a value from 900 seconds (15 minutes) up
to the maximum session duration setting for the role. This setting can
have a value from 1 hour to 12 hours. To learn how to view the maximum
value for your role, see Update the maximum session duration for a role
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_update-role-settings.html#id_roles_update-session-duration)
in the I<IAM User Guide>. The maximum session duration limit applies
when you use the C<AssumeRole*> API operations or the C<assume-role*>
CLI commands. However the limit does not apply when you use those
operations to create a console URL. For more information, see Using IAM
Roles
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html) in
the I<IAM User Guide>.

B<Permissions>

The temporary security credentials created by
C<AssumeRoleWithWebIdentity> can be used to make API calls to any
Amazon Web Services service with the following exception: you cannot
call the STS C<GetFederationToken> or C<GetSessionToken> API
operations.

(Optional) You can pass inline or managed session policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
to this operation. You can pass a single JSON policy document to use as
an inline session policy. You can also specify up to 10 managed policy
Amazon Resource Names (ARNs) to use as managed session policies. The
plaintext that you use for both inline and managed session policies
can't exceed 2,048 characters. Passing policies to this operation
returns new temporary credentials. The resulting session's permissions
are the intersection of the role's identity-based policy and the
session policies. You can use the role's temporary credentials in
subsequent Amazon Web Services API calls to access resources in the
account that owns the role. You cannot use session policies to grant
more permissions than those allowed by the identity-based policy of the
role that is being assumed. For more information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>.

B<Tags>

(Optional) You can configure your IdP to pass attributes into your web
identity token as session tags. Each session tag consists of a key name
and an associated value. For more information about session tags, see
Passing session tags using AssumeRoleWithWebIdentity
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html#id_session-tags_adding-assume-role-idp)
in the I<IAM User Guide>.

You can pass up to 50 session tags. The plaintext session tag keys
canE<rsquo>t exceed 128 characters and the values canE<rsquo>t exceed
256 characters. For these and additional limits, see IAM and STS
Character Limits
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-limits.html#reference_iam-limits-entity-length)
in the I<IAM User Guide>.

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

You can pass a session tag with the same key as a tag that is attached
to the role. When you do, the session tag overrides the role tag with
the same key.

An administrator must grant you the permissions necessary to pass
session tags. The administrator can also create granular permissions to
allow you to pass only specific session tags. For more information, see
Tutorial: Using Tags for Attribute-Based Access Control
(https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_attribute-based-access-control.html)
in the I<IAM User Guide>.

You can set the session tags as transitive. Transitive tags persist
during role chaining. For more information, see Chaining Roles with
Session Tags
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html#id_session-tags_role-chaining)
in the I<IAM User Guide>.

B<Identities>

Before your application can call C<AssumeRoleWithWebIdentity>, you must
have an identity token from a supported identity provider and create a
role that the application can assume. The role that your application
assumes must trust the identity provider that is associated with the
identity token. In other words, the identity provider must be specified
in the role's trust policy.

Calling C<AssumeRoleWithWebIdentity> can result in an entry in your
CloudTrail logs. The entry includes the Subject
(http://openid.net/specs/openid-connect-core-1_0.html#Claims) of the
provided web identity token. We recommend that you avoid using any
personally identifiable information (PII) in this field. For example,
you could instead use a GUID or a pairwise identifier, as suggested in
the OIDC specification
(http://openid.net/specs/openid-connect-core-1_0.html#SubjectIDTypes).

For more information about how to use OIDC federation and the
C<AssumeRoleWithWebIdentity> API, see the following resources:

=over

=item *

Using Web Identity Federation API Operations for Mobile Apps
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_oidc_manual.html)
and Federation Through a Web-based Identity Provider
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#api_assumerolewithwebidentity).

=item *

Amazon Web Services SDK for iOS Developer Guide
(http://aws.amazon.com/sdkforios/) and Amazon Web Services SDK for
Android Developer Guide (http://aws.amazon.com/sdkforandroid/). These
toolkits contain sample apps that show how to invoke the identity
providers. The toolkits then show how to use the information from these
providers to get and use temporary security credentials.

=back

=over 5

=item INPUT


=over 5

=item AssumeRoleWithWebIdentityRequest

=over 5

=item Parameters

=over 5


=item DurationSeconds

The duration, in seconds, of the role session. The value can range from
900 seconds (15 minutes) up to the maximum session duration setting for
the role. This setting can have a value from 1 hour to 12 hours. If you
specify a value higher than this setting, the operation fails. For
example, if you specify a session duration of 12 hours, but your
administrator set the maximum session duration to 6 hours, your
operation fails. To learn how to view the maximum value for your role,
see View the Maximum Session Duration Setting for a Role
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_use.html#id_roles_use_view-role-max-session)
in the I<IAM User Guide>.

By default, the value is set to C<3600> seconds.

The C<DurationSeconds> parameter is separate from the duration of a
console session that you might request using the returned credentials.
The request to the federation endpoint for a console sign-in token
takes a C<SessionDuration> parameter that specifies the maximum length
of the console session. For more information, see Creating a URL that
Enables Federated Users to Access the Amazon Web Services Management
Console
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles_providers_enable-console-custom-url.html)
in the I<IAM User Guide>.

=item Policy

An IAM policy in JSON format that you want to use as an inline session
policy.

This parameter is optional. Passing policies to this operation returns
new temporary credentials. The resulting session's permissions are the
intersection of the role's identity-based policy and the session
policies. You can use the role's temporary credentials in subsequent
Amazon Web Services API calls to access resources in the account that
owns the role. You cannot use session policies to grant more
permissions than those allowed by the identity-based policy of the role
that is being assumed. For more information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>.

The plaintext that you use for both inline and managed session policies
can't exceed 2,048 characters. The JSON policy characters can be any
ASCII character from the space character to the end of the valid
character list (\u0020 through \u00FF). It can also include the tab
(\u0009), linefeed (\u000A), and carriage return (\u000D) characters.

For more information about role session permissions, see Session
policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session).

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

=item PolicyArns

The Amazon Resource Names (ARNs) of the IAM managed policies that you
want to use as managed session policies. The policies must exist in the
same account as the role.

This parameter is optional. You can provide up to 10 managed policy
ARNs. However, the plaintext that you use for both inline and managed
session policies can't exceed 2,048 characters. For more information
about ARNs, see Amazon Resource Names (ARNs) and Amazon Web Services
Service Namespaces
(https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)
in the Amazon Web Services General Reference.

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

Passing policies to this operation returns new temporary credentials.
The resulting session's permissions are the intersection of the role's
identity-based policy and the session policies. You can use the role's
temporary credentials in subsequent Amazon Web Services API calls to
access resources in the account that owns the role. You cannot use
session policies to grant more permissions than those allowed by the
identity-based policy of the role that is being assumed. For more
information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>.

=item ProviderId

The fully qualified host component of the domain name of the OAuth 2.0
identity provider. Do not specify this value for an OpenID Connect
identity provider.

Currently C<www.amazon.com> and C<graph.facebook.com> are the only
supported identity providers for OAuth 2.0 access tokens. Do not
include URL schemes and port numbers.

Do not specify this value for OpenID Connect ID tokens.

=item RoleArn

The Amazon Resource Name (ARN) of the role that the caller is assuming.

Additional considerations apply to Amazon Cognito identity pools that
assume cross-account IAM roles
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies-cross-account-resource-access.html).
The trust policies of these roles must accept the
C<cognito-identity.amazonaws.com> service principal and must contain
the C<cognito-identity.amazonaws.com:aud> condition key to restrict
role assumption to users from your intended identity pools. A policy
that trusts Amazon Cognito identity pools without this condition
creates a risk that a user from an unintended identity pool can assume
the role. For more information, see Trust policies for IAM roles in
Basic (Classic) authentication
(https://docs.aws.amazon.com/cognito/latest/developerguide/iam-roles.html#trust-policies)
in the I<Amazon Cognito Developer Guide>.

=item RoleSessionName

An identifier for the assumed role session. Typically, you pass the
name or identifier that is associated with the user who is using your
application. That way, the temporary security credentials that your
application will use are associated with that user. This session name
is included as part of the ARN and assumed role ID in the
C<AssumedRoleUser> response element.

For security purposes, administrators can view this field in CloudTrail
logs
(https://docs.aws.amazon.com/IAM/latest/UserGuide/cloudtrail-integration.html#cloudtrail-integration_signin-tempcreds)
to help identify who performed an action in Amazon Web Services. Your
administrator might require that you specify your user name as the
session name when you assume the role. For more information, see
C<sts:RoleSessionName>
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_iam-condition-keys.html#ck_rolesessionname).

The regex used to validate this parameter is a string of characters
consisting of upper- and lower-case alphanumeric characters with no
spaces. You can also include underscores or any of the following
characters: =,.@-

=item WebIdentityToken

The OAuth 2.0 access token or OpenID Connect ID token that is provided
by the identity provider. Your application must get this token by
authenticating the user who is using your application with a web
identity provider before the application makes an
C<AssumeRoleWithWebIdentity> call. Timestamps in the token must be
formatted as either an integer or a long integer. Tokens must be signed
using either RSA keys (RS256, RS384, or RS512) or ECDSA keys (ES256,
ES384, or ES512).


=back

=item Required

=over 5

=item RoleArn

=item RoleSessionName

=item WebIdentityToken


=back

=back

=back



=item OUTPUT


=over 5

=item AssumeRoleWithWebIdentityResponse

=over 5

=item Parameters

=over 5


=item AssumedRoleUser

The Amazon Resource Name (ARN) and the assumed role ID, which are
identifiers that you can use to refer to the resulting temporary
security credentials. For example, you can reference these credentials
as a principal in a resource-based policy by using the ARN or assumed
role ID. The ARN and ID include the C<RoleSessionName> that you
specified when you called C<AssumeRole>.

=item Audience

The intended audience (also known as client ID) of the web identity
token. This is traditionally the client identifier issued to the
application that requested the web identity token.

=item Credentials

The temporary security credentials, which include an access key ID, a
secret access key, and a security token.

The size of the security token that STS API operations return is not
fixed. We strongly recommend that you make no assumptions about the
maximum size.

=item PackedPolicySize

A percentage value that indicates the packed size of the session
policies and session tags combined passed in the request. The request
fails if the packed size is greater than 100 percent, which means the
policies and tags exceeded the allowed space.

=item Provider

The issuing authority of the web identity token presented. For OpenID
Connect ID tokens, this contains the value of the C<iss> field. For
OAuth 2.0 access tokens, this contains the value of the C<ProviderId>
parameter that was passed in the C<AssumeRoleWithWebIdentity> request.

=item SourceIdentity

The value of the source identity that is returned in the JSON web token
(JWT) from the identity provider.

You can require users to set a source identity value when they assume a
role. You do this by using the C<sts:SourceIdentity> condition key in a
role trust policy. That way, actions that are taken with the role are
associated with that user. After the source identity is set, the value
cannot be changed. It is present in the request for all actions that
are taken by the role and persists across chained role
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_roles.html#id_roles_terms-and-concepts)
sessions. You can configure your identity provider to use an attribute
associated with your users, like user name or email, as the source
identity when calling C<AssumeRoleWithWebIdentity>. You do this by
adding a claim to the JSON web token. To learn more about OIDC tokens
and claims, see Using Tokens with User Pools
(https://docs.aws.amazon.com/cognito/latest/developerguide/amazon-cognito-user-pools-using-tokens-with-identity-providers.html)
in the I<Amazon Cognito Developer Guide>. For more information about
using source identity, see Monitor and control actions taken with
assumed roles
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_control-access_monitor.html)
in the I<IAM User Guide>.

The regex used to validate this parameter is a string of characters
consisting of upper- and lower-case alphanumeric characters with no
spaces. You can also include underscores or any of the following
characters: =,.@-

=item SubjectFromWebIdentityToken

The unique user identifier that is returned by the identity provider.
This identifier is associated with the C<WebIdentityToken> that was
submitted with the C<AssumeRoleWithWebIdentity> call. The identifier is
typically unique to the user and the application that acquired the
C<WebIdentityToken> (pairwise identifier). For OpenID Connect ID
tokens, this field contains the value returned by the identity provider
as the token's C<sub> (Subject) claim.


=back

=back

=back



=item ERRORS


=over 5

=item MalformedPolicyDocumentException

The request was rejected because the policy document was malformed. The
error message describes the specific error.


=over 5

=item code

MalformedPolicyDocument

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item PackedPolicyTooLargeException

The request was rejected because the total packed size of the session
policies and session tags combined was too large. An Amazon Web
Services conversion compresses the session policy document, session
policy ARNs, and session tags into a packed binary format that has a
separate limit. The error message indicates by percentage how close the
policies and tags are to the upper size limit. For more information,
see Passing Session Tags in STS
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html)
in the I<IAM User Guide>.

You could receive this error even though you meet other defined session
policy and session tag limits. For more information, see IAM and STS
Entity Character Limits
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html#reference_iam-limits-entity-length)
in the I<IAM User Guide>.


=over 5

=item code

PackedPolicyTooLarge

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item IDPRejectedClaimException

The identity provider (IdP) reported that authentication failed. This
might be because the claim is invalid.

If this error is returned for the C<AssumeRoleWithWebIdentity>
operation, it can also mean that the claim has expired or has been
explicitly revoked.


=over 5

=item code

IDPRejectedClaim

=item httpStatusCode

403

=item senderFault

1

=back


=back


=over 5

=item IDPCommunicationErrorException

The request could not be fulfilled because the identity provider (IDP)
that was asked to verify the incoming identity token could not be
reached. This is often a transient error caused by network conditions.
Retry the request a limited number of times so that you don't exceed
the request rate. If the error persists, the identity provider might be
down or not responding.


=over 5

=item code

IDPCommunicationError

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item InvalidIdentityTokenException

The web identity token that was passed could not be validated by Amazon
Web Services. Get a new identity token from the identity provider and
then retry the request.


=over 5

=item code

InvalidIdentityToken

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item ExpiredTokenException

The web identity token that was passed is expired or is not valid. Get
a new identity token from the identity provider and then retry the
request.


=over 5

=item code

ExpiredTokenException

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item RegionDisabledException

STS is not activated in the requested region for the account that is
being asked to generate credentials. The account administrator must use
the IAM console to activate STS in that region. For more information,
see Activating and Deactivating STS in an Amazon Web Services Region
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html#sts-regions-activate-deactivate)
in the I<IAM User Guide>.


=over 5

=item code

RegionDisabledException

=item httpStatusCode

403

=item senderFault

1

=back


=back




=back


=over 5

=item METHOD

POST

=item REQUEST URI

/

=back



=head2 AssumeRoot

Returns a set of short term credentials you can use to perform
privileged tasks on a member account in your organization. You must use
credentials from an Organizations management account or a delegated
administrator account for IAM to call C<AssumeRoot>. You cannot use
root user credentials to make this call.

Before you can launch a privileged session, you must have centralized
root access in your organization. For steps to enable this feature, see
Centralize root access for member accounts
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_root-enable-root-access.html)
in the I<IAM User Guide>.

The STS global endpoint is not supported for AssumeRoot. You must send
this request to a Regional STS endpoint. For more information, see
Endpoints
(https://docs.aws.amazon.com/STS/latest/APIReference/welcome.html#sts-endpoints).

You can track AssumeRoot in CloudTrail logs to determine what actions
were performed in a session. For more information, see Track privileged
tasks in CloudTrail
(https://docs.aws.amazon.com/IAM/latest/UserGuide/cloudtrail-track-privileged-tasks.html)
in the I<IAM User Guide>.

When granting access to privileged tasks you should only grant the
necessary permissions required to perform that task. For more
information, see Security best practices in IAM
(https://docs.aws.amazon.com/IAM/latest/UserGuide/best-practices.html).
In addition, you can use service control policies
(https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_scps.html)
(SCPs) to manage and limit permissions in your organization. See
General examples
(https://docs.aws.amazon.com/organizations/latest/userguide/orgs_manage_policies_scps_examples_general.html)
in the I<Organizations User Guide> for more information on SCPs.

=over 5

=item INPUT


=over 5

=item AssumeRootRequest

=over 5

=item Parameters

=over 5


=item DurationSeconds

The duration, in seconds, of the privileged session. The value can
range from 0 seconds up to the maximum session duration of 900 seconds
(15 minutes). If you specify a value higher than this setting, the
operation fails.

By default, the value is set to C<900> seconds.

=item TargetPrincipal

The member account principal ARN or account ID.

=item TaskPolicyArn

The identity based policy that scopes the session to the privileged
tasks that can be performed. You must use one of following Amazon Web
Services managed policies to scope root session actions:

=over

=item *

IAMAuditRootUserCredentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/security-iam-awsmanpol.html#security-iam-awsmanpol-IAMAuditRootUserCredentials)

=item *

IAMCreateRootUserPassword
(https://docs.aws.amazon.com/IAM/latest/UserGuide/security-iam-awsmanpol.html#security-iam-awsmanpol-IAMCreateRootUserPassword)

=item *

IAMDeleteRootUserCredentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/security-iam-awsmanpol.html#security-iam-awsmanpol-IAMDeleteRootUserCredentials)

=item *

S3UnlockBucketPolicy
(https://docs.aws.amazon.com/IAM/latest/UserGuide/security-iam-awsmanpol.html#security-iam-awsmanpol-S3UnlockBucketPolicy)

=item *

SQSUnlockQueuePolicy
(https://docs.aws.amazon.com/IAM/latest/UserGuide/security-iam-awsmanpol.html#security-iam-awsmanpol-SQSUnlockQueuePolicy)

=back


=back

=item Required

=over 5

=item TargetPrincipal

=item TaskPolicyArn


=back

=back

=back



=item OUTPUT


=over 5

=item AssumeRootResponse

=over 5

=item Parameters

=over 5


=item Credentials

The temporary security credentials, which include an access key ID, a
secret access key, and a security token.

The size of the security token that STS API operations return is not
fixed. We strongly recommend that you make no assumptions about the
maximum size.

=item SourceIdentity

The source identity specified by the principal that is calling the
C<AssumeRoot> operation.

You can use the C<aws:SourceIdentity> condition key to control access
based on the value of source identity. For more information about using
source identity, see Monitor and control actions taken with assumed
roles
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_control-access_monitor.html)
in the I<IAM User Guide>.

The regex used to validate this parameter is a string of characters
consisting of upper- and lower-case alphanumeric characters with no
spaces. You can also include underscores or any of the following
characters: =,.@-


=back

=back

=back



=item ERRORS


=over 5

=item RegionDisabledException

STS is not activated in the requested region for the account that is
being asked to generate credentials. The account administrator must use
the IAM console to activate STS in that region. For more information,
see Activating and Deactivating STS in an Amazon Web Services Region
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html#sts-regions-activate-deactivate)
in the I<IAM User Guide>.


=over 5

=item code

RegionDisabledException

=item httpStatusCode

403

=item senderFault

1

=back


=back


=over 5

=item ExpiredTokenException

The web identity token that was passed is expired or is not valid. Get
a new identity token from the identity provider and then retry the
request.


=over 5

=item code

ExpiredTokenException

=item httpStatusCode

400

=item senderFault

1

=back


=back




=back


=over 5

=item METHOD

POST

=item REQUEST URI

/

=back



=head2 DecodeAuthorizationMessage

Decodes additional information about the authorization status of a
request from an encoded message returned in response to an Amazon Web
Services request.

For example, if a user is not authorized to perform an operation that
he or she has requested, the request returns a
C<Client.UnauthorizedOperation> response (an HTTP 403 response). Some
Amazon Web Services operations additionally return an encoded message
that can provide details about this authorization failure.

Only certain Amazon Web Services operations return an encoded
authorization message. The documentation for an individual operation
indicates whether that operation returns an encoded message in addition
to returning an HTTP code.

The message is encoded because the details of the authorization status
can contain privileged information that the user who requested the
operation should not see. To decode an authorization status message, a
user must be granted permissions through an IAM policy
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html)
to request the C<DecodeAuthorizationMessage>
(C<sts:DecodeAuthorizationMessage>) action.

The decoded message includes the following type of information:

=over

=item *

Whether the request was denied due to an explicit deny or due to the
absence of an explicit allow. For more information, see Determining
Whether a Request is Allowed or Denied
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_evaluation-logic.html#policy-eval-denyallow)
in the I<IAM User Guide>.

=item *

The principal who made the request.

=item *

The requested action.

=item *

The requested resource.

=item *

The values of condition keys in the context of the user's request.

=back

=over 5

=item INPUT


=over 5

=item DecodeAuthorizationMessageRequest

=over 5

=item Parameters

=over 5


=item EncodedMessage

The encoded message that was returned with the response.


=back

=item Required

=over 5

=item EncodedMessage


=back

=back

=back



=item OUTPUT


=over 5

=item DecodeAuthorizationMessageResponse

=over 5

=item Parameters

=over 5


=item DecodedMessage

The API returns a response with the decoded message.


=back

=back

=back



=item ERRORS


=over 5

=item InvalidAuthorizationMessageException

The error returned if the message passed to
C<DecodeAuthorizationMessage> was invalid. This can happen if the token
contains invalid characters, such as line breaks, or if the message has
expired.


=over 5

=item code

InvalidAuthorizationMessageException

=item httpStatusCode

400

=item senderFault

1

=back


=back




=back


=over 5

=item METHOD

POST

=item REQUEST URI

/

=back



=head2 GetAccessKeyInfo

Returns the account identifier for the specified access key ID.

Access keys consist of two parts: an access key ID (for example,
C<AKIAIOSFODNN7EXAMPLE>) and a secret access key (for example,
C<wJalrXUtnFEMI/K7MDENG/bPxRfiCYEXAMPLEKEY>). For more information
about access keys, see Managing Access Keys for IAM Users
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_access-keys.html)
in the I<IAM User Guide>.

When you pass an access key ID to this operation, it returns the ID of
the Amazon Web Services account to which the keys belong. Access key
IDs beginning with C<AKIA> are long-term credentials for an IAM user or
the Amazon Web Services account root user. Access key IDs beginning
with C<ASIA> are temporary credentials that are created using STS
operations. If the account in the response belongs to you, you can sign
in as the root user and review your root user access keys. Then, you
can pull a credentials report
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_getting-report.html)
to learn which IAM user owns the keys. To learn who requested the
temporary credentials for an C<ASIA> access key, view the STS events in
your CloudTrail logs
(https://docs.aws.amazon.com/IAM/latest/UserGuide/cloudtrail-integration.html)
in the I<IAM User Guide>.

This operation does not indicate the state of the access key. The key
might be active, inactive, or deleted. Active keys might not have
permissions to perform an operation. Providing a deleted access key
might return an error that the key doesn't exist.

=over 5

=item INPUT


=over 5

=item GetAccessKeyInfoRequest

=over 5

=item Parameters

=over 5


=item AccessKeyId

The identifier of an access key.

This parameter allows (through its regex pattern) a string of
characters that can consist of any upper- or lowercase letter or digit.


=back

=item Required

=over 5

=item AccessKeyId


=back

=back

=back



=item OUTPUT


=over 5

=item GetAccessKeyInfoResponse

=over 5

=item Parameters

=over 5


=item Account

The number used to identify the Amazon Web Services account.


=back

=back

=back



=item ERRORS

=over 5

=item NONE

=back



=back


=over 5

=item METHOD

POST

=item REQUEST URI

/

=back



=head2 GetCallerIdentity

Returns details about the IAM user or role whose credentials are used
to call the operation.

No permissions are required to perform this operation. If an
administrator attaches a policy to your identity that explicitly denies
access to the C<sts:GetCallerIdentity> action, you can still perform
this operation. Permissions are not required because the same
information is returned when access is denied. To view an example
response, see I Am Not Authorized to Perform:
iam:DeleteVirtualMFADevice
(https://docs.aws.amazon.com/IAM/latest/UserGuide/troubleshoot_general.html#troubleshoot_general_access-denied-delete-mfa)
in the I<IAM User Guide>.

=over 5

=item INPUT


=over 5

=item GetCallerIdentityRequest

=over 5

=item Parameters

=over 5



=back

=item Required

=over 5




=back

=back

=back



=item OUTPUT


=over 5

=item GetCallerIdentityResponse

=over 5

=item Parameters

=over 5


=item Account

The Amazon Web Services account ID number of the account that owns or
contains the calling entity.

=item Arn

The Amazon Web Services ARN associated with the calling entity.

=item UserId

The unique identifier of the calling entity. The exact value depends on
the type of entity that is making the call. The values returned are
those listed in the B<aws:userid> column in the Principal table
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_policies_variables.html#principaltable)
found on the B<Policy Variables> reference page in the I<IAM User
Guide>.


=back

=back

=back



=item ERRORS

=over 5

=item NONE

=back



=back


=over 5

=item METHOD

POST

=item REQUEST URI

/

=back



=head2 GetDelegatedAccessToken

Exchanges a trade-in token for temporary Amazon Web Services
credentials with the permissions associated with the assumed principal.
This operation allows you to obtain credentials for a specific
principal based on a trade-in token, enabling delegation of access to
Amazon Web Services resources.

=over 5

=item INPUT


=over 5

=item GetDelegatedAccessTokenRequest

=over 5

=item Parameters

=over 5


=item TradeInToken

The token to exchange for temporary Amazon Web Services credentials.
This token must be valid and unexpired at the time of the request.


=back

=item Required

=over 5

=item TradeInToken


=back

=back

=back



=item OUTPUT


=over 5

=item GetDelegatedAccessTokenResponse

=over 5

=item Parameters

=over 5


=item AssumedPrincipal

The Amazon Resource Name (ARN) of the principal that was assumed when
obtaining the delegated access token. This ARN identifies the IAM
entity whose permissions are granted by the temporary credentials.

=item Credentials


=item PackedPolicySize

The percentage of the maximum policy size that is used by the session
policy. The policy size is calculated as the sum of all the session
policies and permission boundaries attached to the session. If the
packed size exceeds 100%, the request fails.


=back

=back

=back



=item ERRORS


=over 5

=item ExpiredTradeInTokenException

The trade-in token provided in the request has expired and can no
longer be exchanged for credentials. Request a new token and retry the
operation.


=over 5

=item code

ExpiredTradeInTokenException

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item RegionDisabledException

STS is not activated in the requested region for the account that is
being asked to generate credentials. The account administrator must use
the IAM console to activate STS in that region. For more information,
see Activating and Deactivating STS in an Amazon Web Services Region
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html#sts-regions-activate-deactivate)
in the I<IAM User Guide>.


=over 5

=item code

RegionDisabledException

=item httpStatusCode

403

=item senderFault

1

=back


=back


=over 5

=item PackedPolicyTooLargeException

The request was rejected because the total packed size of the session
policies and session tags combined was too large. An Amazon Web
Services conversion compresses the session policy document, session
policy ARNs, and session tags into a packed binary format that has a
separate limit. The error message indicates by percentage how close the
policies and tags are to the upper size limit. For more information,
see Passing Session Tags in STS
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html)
in the I<IAM User Guide>.

You could receive this error even though you meet other defined session
policy and session tag limits. For more information, see IAM and STS
Entity Character Limits
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html#reference_iam-limits-entity-length)
in the I<IAM User Guide>.


=over 5

=item code

PackedPolicyTooLarge

=item httpStatusCode

400

=item senderFault

1

=back


=back




=back


=over 5

=item METHOD

POST

=item REQUEST URI

/

=back



=head2 GetFederationToken

Returns a set of temporary security credentials (consisting of an
access key ID, a secret access key, and a security token) for a user. A
typical use is in a proxy application that gets temporary security
credentials on behalf of distributed applications inside a corporate
network.

You must call the C<GetFederationToken> operation using the long-term
security credentials of an IAM user. As a result, this call is
appropriate in contexts where those credentials can be safeguarded,
usually in a server-based application. For a comparison of
C<GetFederationToken> with the other API operations that produce
temporary credentials, see Requesting Temporary Security Credentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html)
and Compare STS credentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_sts-comparison.html)
in the I<IAM User Guide>.

Although it is possible to call C<GetFederationToken> using the
security credentials of an Amazon Web Services account root user rather
than an IAM user that you create for the purpose of a proxy
application, we do not recommend it. For more information, see
Safeguard your root user credentials and don't use them for everyday
tasks
(https://docs.aws.amazon.com/IAM/latest/UserGuide/best-practices.html#lock-away-credentials)
in the I<IAM User Guide>.

You can create a mobile-based or browser-based app that can
authenticate users using a web identity provider like Login with
Amazon, Facebook, Google, or an OpenID Connect-compatible identity
provider. In this case, we recommend that you use Amazon Cognito
(http://aws.amazon.com/cognito/) or C<AssumeRoleWithWebIdentity>. For
more information, see Federation Through a Web-based Identity Provider
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#api_assumerolewithwebidentity)
in the I<IAM User Guide>.

B<Session duration>

The temporary credentials are valid for the specified duration, from
900 seconds (15 minutes) up to a maximum of 129,600 seconds (36 hours).
The default session duration is 43,200 seconds (12 hours). Temporary
credentials obtained by using the root user credentials have a maximum
duration of 3,600 seconds (1 hour).

B<Permissions>

You can use the temporary credentials created by C<GetFederationToken>
in any Amazon Web Services service with the following exceptions:

=over

=item *

You cannot call any IAM operations using the CLI or the Amazon Web
Services API. This limitation does not apply to console sessions.

=item *

You cannot call any STS operations except C<GetCallerIdentity>.

=back

You can use temporary credentials for single sign-on (SSO) to the
console.

You must pass an inline or managed session policy
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
to this operation. You can pass a single JSON policy document to use as
an inline session policy. You can also specify up to 10 managed policy
Amazon Resource Names (ARNs) to use as managed session policies. The
plaintext that you use for both inline and managed session policies
can't exceed 2,048 characters.

Though the session policy parameters are optional, if you do not pass a
policy, then the resulting federated user session has no permissions.
When you pass session policies, the session permissions are the
intersection of the IAM user policies and the session policies that you
pass. This gives you a way to further restrict the permissions for a
federated user. You cannot use session policies to grant more
permissions than those that are defined in the permissions policy of
the IAM user. For more information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>. For information about using
C<GetFederationToken> to create temporary security credentials, see
GetFederationTokenE<mdash>Federation Through a Custom Identity Broker
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#api_getfederationtoken).

You can use the credentials to access a resource that has a
resource-based policy. If that policy specifically references the
federated user session in the C<Principal> element of the policy, the
session has the permissions allowed by the policy. These permissions
are granted in addition to the permissions granted by the session
policies.

B<Tags>

(Optional) You can pass tag key-value pairs to your session. These are
called session tags. For more information about session tags, see
Passing Session Tags in STS
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html)
in the I<IAM User Guide>.

You can create a mobile-based or browser-based app that can
authenticate users using a web identity provider like Login with
Amazon, Facebook, Google, or an OpenID Connect-compatible identity
provider. In this case, we recommend that you use Amazon Cognito
(http://aws.amazon.com/cognito/) or C<AssumeRoleWithWebIdentity>. For
more information, see Federation Through a Web-based Identity Provider
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#api_assumerolewithwebidentity)
in the I<IAM User Guide>.

An administrator must grant you the permissions necessary to pass
session tags. The administrator can also create granular permissions to
allow you to pass only specific session tags. For more information, see
Tutorial: Using Tags for Attribute-Based Access Control
(https://docs.aws.amazon.com/IAM/latest/UserGuide/tutorial_attribute-based-access-control.html)
in the I<IAM User Guide>.

Tag keyE<ndash>value pairs are not case sensitive, but case is
preserved. This means that you cannot have separate C<Department> and
C<department> tag keys. Assume that the user that you are federating
has the C<Department>=C<Marketing> tag and you pass the
C<department>=C<engineering> session tag. C<Department> and
C<department> are not saved as separate tags, and the session tag
passed in the request takes precedence over the user tag.

=over 5

=item INPUT


=over 5

=item GetFederationTokenRequest

=over 5

=item Parameters

=over 5


=item DurationSeconds

The duration, in seconds, that the session should last. Acceptable
durations for federation sessions range from 900 seconds (15 minutes)
to 129,600 seconds (36 hours), with 43,200 seconds (12 hours) as the
default. Sessions obtained using root user credentials are restricted
to a maximum of 3,600 seconds (one hour). If the specified duration is
longer than one hour, the session obtained by using root user
credentials defaults to one hour.

=item Name

The name of the federated user. The name is used as an identifier for
the temporary security credentials (such as C<Bob>). For example, you
can reference the federated user name in a resource-based policy, such
as in an Amazon S3 bucket policy.

The regex used to validate this parameter is a string of characters
consisting of upper- and lower-case alphanumeric characters with no
spaces. You can also include underscores or any of the following
characters: =,.@-

=item Policy

An IAM policy in JSON format that you want to use as an inline session
policy.

You must pass an inline or managed session policy
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
to this operation. You can pass a single JSON policy document to use as
an inline session policy. You can also specify up to 10 managed policy
Amazon Resource Names (ARNs) to use as managed session policies.

This parameter is optional. However, if you do not pass any session
policies, then the resulting federated user session has no permissions.

When you pass session policies, the session permissions are the
intersection of the IAM user policies and the session policies that you
pass. This gives you a way to further restrict the permissions for a
federated user. You cannot use session policies to grant more
permissions than those that are defined in the permissions policy of
the IAM user. For more information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>.

The resulting credentials can be used to access a resource that has a
resource-based policy. If that policy specifically references the
federated user session in the C<Principal> element of the policy, the
session has the permissions allowed by the policy. These permissions
are granted in addition to the permissions that are granted by the
session policies.

The plaintext that you use for both inline and managed session policies
can't exceed 2,048 characters. The JSON policy characters can be any
ASCII character from the space character to the end of the valid
character list (\u0020 through \u00FF). It can also include the tab
(\u0009), linefeed (\u000A), and carriage return (\u000D) characters.

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

=item PolicyArns

The Amazon Resource Names (ARNs) of the IAM managed policies that you
want to use as a managed session policy. The policies must exist in the
same account as the IAM user that is requesting federated access.

You must pass an inline or managed session policy
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
to this operation. You can pass a single JSON policy document to use as
an inline session policy. You can also specify up to 10 managed policy
Amazon Resource Names (ARNs) to use as managed session policies. The
plaintext that you use for both inline and managed session policies
can't exceed 2,048 characters. You can provide up to 10 managed policy
ARNs. For more information about ARNs, see Amazon Resource Names (ARNs)
and Amazon Web Services Service Namespaces
(https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html)
in the Amazon Web Services General Reference.

This parameter is optional. However, if you do not pass any session
policies, then the resulting federated user session has no permissions.

When you pass session policies, the session permissions are the
intersection of the IAM user policies and the session policies that you
pass. This gives you a way to further restrict the permissions for a
federated user. You cannot use session policies to grant more
permissions than those that are defined in the permissions policy of
the IAM user. For more information, see Session Policies
(https://docs.aws.amazon.com/IAM/latest/UserGuide/access_policies.html#policies_session)
in the I<IAM User Guide>.

The resulting credentials can be used to access a resource that has a
resource-based policy. If that policy specifically references the
federated user session in the C<Principal> element of the policy, the
session has the permissions allowed by the policy. These permissions
are granted in addition to the permissions that are granted by the
session policies.

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

=item Tags

A list of session tags. Each session tag consists of a key name and an
associated value. For more information about session tags, see Passing
Session Tags in STS
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html)
in the I<IAM User Guide>.

This parameter is optional. You can pass up to 50 session tags. The
plaintext session tag keys canE<rsquo>t exceed 128 characters and the
values canE<rsquo>t exceed 256 characters. For these and additional
limits, see IAM and STS Character Limits
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-limits.html#reference_iam-limits-entity-length)
in the I<IAM User Guide>.

An Amazon Web Services conversion compresses the passed inline session
policy, managed policy ARNs, and session tags into a packed binary
format that has a separate limit. Your request can fail for this limit
even if your plaintext meets the other requirements. The
C<PackedPolicySize> response element indicates by percentage how close
the policies and tags for your request are to the upper size limit.

You can pass a session tag with the same key as a tag that is already
attached to the user you are federating. When you do, session tags
override a user tag with the same key.

Tag keyE<ndash>value pairs are not case sensitive, but case is
preserved. This means that you cannot have separate C<Department> and
C<department> tag keys. Assume that the role has the
C<Department>=C<Marketing> tag and you pass the
C<department>=C<engineering> session tag. C<Department> and
C<department> are not saved as separate tags, and the session tag
passed in the request takes precedence over the role tag.


=back

=item Required

=over 5

=item Name


=back

=back

=back



=item OUTPUT


=over 5

=item GetFederationTokenResponse

=over 5

=item Parameters

=over 5


=item Credentials

The temporary security credentials, which include an access key ID, a
secret access key, and a security (or session) token.

The size of the security token that STS API operations return is not
fixed. We strongly recommend that you make no assumptions about the
maximum size.

=item FederatedUser

Identifiers for the federated user associated with the credentials
(such as C<arn:aws:sts::123456789012:federated-user/Bob> or
C<123456789012:Bob>). You can use the federated user's ARN in your
resource-based policies, such as an Amazon S3 bucket policy.

=item PackedPolicySize

A percentage value that indicates the packed size of the session
policies and session tags combined passed in the request. The request
fails if the packed size is greater than 100 percent, which means the
policies and tags exceeded the allowed space.


=back

=back

=back



=item ERRORS


=over 5

=item MalformedPolicyDocumentException

The request was rejected because the policy document was malformed. The
error message describes the specific error.


=over 5

=item code

MalformedPolicyDocument

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item PackedPolicyTooLargeException

The request was rejected because the total packed size of the session
policies and session tags combined was too large. An Amazon Web
Services conversion compresses the session policy document, session
policy ARNs, and session tags into a packed binary format that has a
separate limit. The error message indicates by percentage how close the
policies and tags are to the upper size limit. For more information,
see Passing Session Tags in STS
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_session-tags.html)
in the I<IAM User Guide>.

You could receive this error even though you meet other defined session
policy and session tag limits. For more information, see IAM and STS
Entity Character Limits
(https://docs.aws.amazon.com/IAM/latest/UserGuide/reference_iam-quotas.html#reference_iam-limits-entity-length)
in the I<IAM User Guide>.


=over 5

=item code

PackedPolicyTooLarge

=item httpStatusCode

400

=item senderFault

1

=back


=back


=over 5

=item RegionDisabledException

STS is not activated in the requested region for the account that is
being asked to generate credentials. The account administrator must use
the IAM console to activate STS in that region. For more information,
see Activating and Deactivating STS in an Amazon Web Services Region
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html#sts-regions-activate-deactivate)
in the I<IAM User Guide>.


=over 5

=item code

RegionDisabledException

=item httpStatusCode

403

=item senderFault

1

=back


=back




=back


=over 5

=item METHOD

POST

=item REQUEST URI

/

=back



=head2 GetSessionToken

Returns a set of temporary credentials for an Amazon Web Services
account or IAM user. The credentials consist of an access key ID, a
secret access key, and a security token. Typically, you use
C<GetSessionToken> if you want to use MFA to protect programmatic calls
to specific Amazon Web Services API operations like Amazon EC2
C<StopInstances>.

MFA-enabled IAM users must call C<GetSessionToken> and submit an MFA
code that is associated with their MFA device. Using the temporary
security credentials that the call returns, IAM users can then make
programmatic calls to API operations that require MFA authentication.
An incorrect MFA code causes the API to return an access denied error.
For a comparison of C<GetSessionToken> with the other API operations
that produce temporary credentials, see Requesting Temporary Security
Credentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html)
and Compare STS credentials
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_sts-comparison.html)
in the I<IAM User Guide>.

No permissions are required for users to perform this operation. The
purpose of the C<sts:GetSessionToken> operation is to authenticate the
user using MFA. You cannot use policies to control authentication
operations. For more information, see Permissions for GetSessionToken
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_control-access_getsessiontoken.html)
in the I<IAM User Guide>.

B<Session Duration>

The C<GetSessionToken> operation must be called by using the long-term
Amazon Web Services security credentials of an IAM user. Credentials
that are created by IAM users are valid for the duration that you
specify. This duration can range from 900 seconds (15 minutes) up to a
maximum of 129,600 seconds (36 hours), with a default of 43,200 seconds
(12 hours). Credentials based on account credentials can range from 900
seconds (15 minutes) up to 3,600 seconds (1 hour), with a default of 1
hour.

B<Permissions>

The temporary security credentials created by C<GetSessionToken> can be
used to make API calls to any Amazon Web Services service with the
following exceptions:

=over

=item *

You cannot call any IAM API operations unless MFA authentication
information is included in the request.

=item *

You cannot call any STS API I<except> C<AssumeRole> or
C<GetCallerIdentity>.

=back

The credentials that C<GetSessionToken> returns are based on
permissions associated with the IAM user whose credentials were used to
call the operation. The temporary credentials have the same permissions
as the IAM user.

Although it is possible to call C<GetSessionToken> using the security
credentials of an Amazon Web Services account root user rather than an
IAM user, we do not recommend it. If C<GetSessionToken> is called using
root user credentials, the temporary credentials have root user
permissions. For more information, see Safeguard your root user
credentials and don't use them for everyday tasks
(https://docs.aws.amazon.com/IAM/latest/UserGuide/best-practices.html#lock-away-credentials)
in the I<IAM User Guide>

For more information about using C<GetSessionToken> to create temporary
credentials, see Temporary Credentials for Users in Untrusted
Environments
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_request.html#api_getsessiontoken)
in the I<IAM User Guide>.

=over 5

=item INPUT


=over 5

=item GetSessionTokenRequest

=over 5

=item Parameters

=over 5


=item DurationSeconds

The duration, in seconds, that the credentials should remain valid.
Acceptable durations for IAM user sessions range from 900 seconds (15
minutes) to 129,600 seconds (36 hours), with 43,200 seconds (12 hours)
as the default. Sessions for Amazon Web Services account owners are
restricted to a maximum of 3,600 seconds (one hour). If the duration is
longer than one hour, the session for Amazon Web Services account
owners defaults to one hour.

=item SerialNumber

The identification number of the MFA device that is associated with the
IAM user who is making the C<GetSessionToken> call. Specify this value
if the IAM user has a policy that requires MFA authentication. The
value is either the serial number for a hardware device (such as
C<GAHT12345678>) or an Amazon Resource Name (ARN) for a virtual device
(such as C<arn:aws:iam::123456789012:mfa/user>). You can find the
device for an IAM user by going to the Amazon Web Services Management
Console and viewing the user's security credentials.

The regex used to validate this parameter is a string of characters
consisting of upper- and lower-case alphanumeric characters with no
spaces. You can also include underscores or any of the following
characters: =,.@:/-

=item TokenCode

The value provided by the MFA device, if MFA is required. If any policy
requires the IAM user to submit an MFA code, specify this value. If MFA
authentication is required, the user must provide a code when
requesting a set of temporary security credentials. A user who fails to
provide the code receives an "access denied" response when requesting
resources that require MFA authentication.

The format for this parameter, as described by its regex pattern, is a
sequence of six numeric digits.


=back

=item Required

=over 5




=back

=back

=back



=item OUTPUT


=over 5

=item GetSessionTokenResponse

=over 5

=item Parameters

=over 5


=item Credentials

The temporary security credentials, which include an access key ID, a
secret access key, and a security (or session) token.

The size of the security token that STS API operations return is not
fixed. We strongly recommend that you make no assumptions about the
maximum size.


=back

=back

=back



=item ERRORS


=over 5

=item RegionDisabledException

STS is not activated in the requested region for the account that is
being asked to generate credentials. The account administrator must use
the IAM console to activate STS in that region. For more information,
see Activating and Deactivating STS in an Amazon Web Services Region
(https://docs.aws.amazon.com/IAM/latest/UserGuide/id_credentials_temp_enable-regions.html#sts-regions-activate-deactivate)
in the I<IAM User Guide>.


=over 5

=item code

RegionDisabledException

=item httpStatusCode

403

=item senderFault

1

=back


=back




=back


=over 5

=item METHOD

POST

=item REQUEST URI

/

=back



=head2 GetWebIdentityToken

Returns a signed JSON Web Token (JWT) that represents the calling
Amazon Web Services identity. The returned JWT can be used to
authenticate with external services that support OIDC discovery. The
token is signed by Amazon Web Services STS and can be publicly verified
using the verification keys published at the issuer's JWKS endpoint.

=over 5

=item INPUT


=over 5

=item GetWebIdentityTokenRequest

=over 5

=item Parameters

=over 5


=item Audience

The intended recipient of the web identity token. This value populates
the C<aud> claim in the JWT and should identify the service or
application that will validate and use the token. The external service
should verify this claim to ensure the token was intended for their
use.

=item DurationSeconds

The duration, in seconds, for which the JSON Web Token (JWT) will
remain valid. The value can range from 60 seconds (1 minute) to 3600
seconds (1 hour). If not specified, the default duration is 300 seconds
(5 minutes). The token is designed to be short-lived and should be used
for proof of identity, then exchanged for credentials or short-lived
tokens in the external service.

=item SigningAlgorithm

The cryptographic algorithm to use for signing the JSON Web Token
(JWT). Valid values are RS256 (RSA with SHA-256) and ES384 (ECDSA using
P-384 curve with SHA-384).

=item Tags

An optional list of tags to include in the JSON Web Token (JWT). These
tags are added as custom claims to the JWT and can be used by the
downstream service for authorization decisions.


=back

=item Required

=over 5

=item Audience

=item SigningAlgorithm


=back

=back

=back



=item OUTPUT


=over 5

=item GetWebIdentityTokenResponse

=over 5

=item Parameters

=over 5


=item Expiration

The date and time when the web identity token expires, in UTC. The
expiration is determined by adding the C<DurationSeconds> value to the
time the token was issued. After this time, the token should no longer
be considered valid.

=item WebIdentityToken

A signed JSON Web Token (JWT) that represents the caller's Amazon Web
Services identity. The token contains standard JWT claims such as
subject, audience, expiration time, and additional identity attributes
added by STS as custom claims. You can also add your own custom claims
to the token by passing tags as request parameters to the
C<GetWebIdentityToken> API. The token is signed using the specified
signing algorithm and can be verified using the verification keys
available at the issuer's JWKS endpoint.


=back

=back

=back



=item ERRORS


=over 5

=item SessionDurationEscalationException

The requested token duration would extend the session beyond its
original expiration time. You cannot use this operation to extend the
lifetime of a session beyond what was granted when the session was
originally created.


=over 5

=item code

SessionDurationEscalationException

=item httpStatusCode

403

=item senderFault

1

=back


=back


=over 5

=item OutboundWebIdentityFederationDisabledException

The outbound web identity federation feature is not enabled for this
account. To use this feature, you must first enable it through the
Amazon Web Services Management Console or API.


=over 5

=item code

OutboundWebIdentityFederationDisabledException

=item httpStatusCode

403

=item senderFault

1

=back


=back


=over 5

=item JWTPayloadSizeExceededException

The requested token payload size exceeds the maximum allowed size.
Reduce the number of request tags included in the
C<GetWebIdentityToken> API call to reduce the token payload size.


=over 5

=item code

JWTPayloadSizeExceededException

=item httpStatusCode

400

=item senderFault

1

=back


=back




=back


=over 5

=item METHOD

POST

=item REQUEST URI

/

=back



=head1 NOTES

Autogenerated at Mon Jul  6 12:50:57 2026

=head1 LICENSE AND COPYRIGHT

This module is free software it may be used, redistributed and/or
modified under the same terms as Perl itself.

=cut  
